@@ -1215,7 +1215,7 @@ int pilFitsHdrDeleteKeys(const char *filename, const char *keyname, int ext)
     assert(filename != NULL);
     assert(keyname != NULL);
 
-    if (fits_open_file(&file, filename, READWRITE, &status)) {
+    if (ffopen(&file, filename, READWRITE, &status)) {
         pilMsgError(fid, "Cannot open file `%s'", filename);
         return EXIT_FAILURE;
     }
@@ -1286,7 +1286,7 @@ int pilFitsHdrCopy(const char *filename, unsigned int target, const char *hint,
         return EXIT_FAILURE;
     }
 
-    if (fits_open_file(&file, filename, READWRITE, &status)) {
+    if (ffopen(&file, filename, READWRITE, &status)) {
         pilMsgError(fctid, "Cannot open file `%s'", filename);
         return EXIT_FAILURE;
     }
