@@ -39,7 +39,6 @@
 #include <fors_tools.h>
 #include <vimos_dfs.h>
 #include <vimos_response.h>
-#include <fors_qc.h>
 #include "wavelength_calibration.h"
 #include "hdrl.h"
 
@@ -1945,6 +1944,7 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
                               "scientific frame header");
                 cpl_image_delete(fringes);
                 cpl_image_delete(stacked);
+                cpl_image_delete(stacked_err);
                 cpl_image_delete(sky_stacked);
                 cpl_propertylist_delete(header);
                 return -1;
@@ -2346,7 +2346,7 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
 
             if (time_normal) {
                 cpl_propertylist_update_string(header, "BUNIT", "ADU/s");
-                cpl_image_divide_scalar(images[0], alltime);
+                cpl_image_divide_scalar(images[0], alltime / mos);
             }
             else {
                 cpl_propertylist_update_string(header, "BUNIT", "ADU");
@@ -2364,7 +2364,7 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
 
 
             if (time_normal) {
-                cpl_image_divide_scalar(images[1], alltime);
+                cpl_image_divide_scalar(images[1], alltime / mos);
             }
 
             if (dfs_save_image(frameset, images[1], reduced_sky_tag, header,
@@ -2405,7 +2405,7 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
                 calibrated = mos_propagate_photometry_error(science_images, 
                                                   science_images_err, response_interp,
                                                   ext_table, startwavelength,
-                                                  dispersion, gain, alltime,
+                                                  dispersion, gain, alltime / mos,
                                                   airmass);
 
                 cpl_table_delete(ext_table);
@@ -2429,7 +2429,7 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
 
             if (time_normal) {
                 cpl_propertylist_update_string(header, "BUNIT", "ADU/s");
-                cpl_image_divide_scalar(images[2], alltime);
+                cpl_image_divide_scalar(images[2], alltime / mos);
             }
             else {
                 cpl_propertylist_update_string(header, "BUNIT", "ADU");
