@@ -68,6 +68,7 @@
 #include "vmspecphottable.h"
 #include "vmmosutils.h"
 #include "vmcpl.h"
+#include "vimos_dfs.h"
 
 
 #define MAX_COMMENT_LENGTH (80)
@@ -1127,7 +1128,14 @@ vmmosobsstare(PilSetOfFrames *sof)
 
 
   /*
-   *  Bias removal from MOS frame
+   * Now go for the bias subtraction
+   * 
+   * NOTE: This includes the overscan subtraction if biasMethod = BIAS_ZMASTER,
+   * which is the default. Since the overscan region in the master bias has 
+   * been created with growOverscans, there is some extra noise added here,
+   * but this can probably be ignored. A better approach is to use the method
+   * used in the MOS pipeline: subtract overscan for each individual frame,
+   * then subtract bias.
    */
 
   cpl_msg_info(task, "Bias removal...");
@@ -1429,7 +1437,7 @@ vmmosobsstare(PilSetOfFrames *sof)
 
   deleteImage(outSpSkyFra[0]);
   deleteImage(outSpSkyFra[1]);
-  pil_free(outSpSkyFra);
+  cpl_free(outSpSkyFra);
 
   if (!outSpEx2D) {
     cpl_msg_error(task, "Failure in 2D extraction of spectra");
@@ -1451,7 +1459,7 @@ vmmosobsstare(PilSetOfFrames *sof)
     cpl_msg_error(task, "Failure in sky subtraction in long slits");
     deleteImage(outSpEx2D[0]);
     deleteImage(outSpEx2D[1]);
-    pil_free(outSpEx2D);
+    cpl_free(outSpEx2D);
     deleteExtractionTable(extractionTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1508,10 +1516,10 @@ vmmosobsstare(PilSetOfFrames *sof)
                                  slitTolerance,specFrac))) {
     cpl_msg_error(task, "Iteration on object detection failed");
     deleteImage(outSpEx2D[0]);
-    pil_free(outSpEx2D);
+    cpl_free(outSpEx2D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteExtractionTable(extractionTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1520,14 +1528,14 @@ vmmosobsstare(PilSetOfFrames *sof)
   deleteWindowTable(dummyWindow);
   deleteExtractionTable(extractionTable);
   deleteImage(outSpEx2D[0]);
-  pil_free(outSpEx2D);
+  cpl_free(outSpEx2D);
 
   if (numObjsInWindowTable(windowTable) < 1) {
     cpl_msg_error(task, "No objects found!");
     deleteWindowTable(windowTable);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     return EXIT_FAILURE;
   }
 
@@ -1556,7 +1564,7 @@ vmmosobsstare(PilSetOfFrames *sof)
   if (error) {
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1599,10 +1607,10 @@ vmmosobsstare(PilSetOfFrames *sof)
     if (error) {
       deleteImage(imaSpEx1D[0]);
       deleteImage(imaSpEx1D[1]);
-      pil_free(imaSpEx1D);
+      cpl_free(imaSpEx1D);
       deleteImage(outSpSkyEx[0]);
       deleteImage(outSpSkyEx[1]);
-      pil_free(outSpSkyEx);
+      cpl_free(outSpSkyEx);
       deleteObjectTable(objectTable);
       deleteWindowTable(windowTable);
       return EXIT_FAILURE;
@@ -1637,10 +1645,10 @@ vmmosobsstare(PilSetOfFrames *sof)
       deleteTable(sphotTable);
       deleteImage(imaSpEx1D[0]);
       deleteImage(imaSpEx1D[1]);
-      pil_free(imaSpEx1D);
+      cpl_free(imaSpEx1D);
       deleteImage(outSpSkyEx[0]);
       deleteImage(outSpSkyEx[1]);
-      pil_free(outSpSkyEx);
+      cpl_free(outSpSkyEx);
       deleteObjectTable(objectTable);
       deleteWindowTable(windowTable);
       return EXIT_FAILURE;
@@ -1706,10 +1714,10 @@ vmmosobsstare(PilSetOfFrames *sof)
     deleteImage(imaSpEx1DCal);
     deleteImage(imaSpEx1D[0]);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1725,7 +1733,7 @@ vmmosobsstare(PilSetOfFrames *sof)
   removeDescriptor(&(imaSpEx1D[0]->descs), 
                    pilTrnGetKeyword("TplExposureNumber"));
 
-  strlower(strcpy(output1DName, mosReducedCategory));
+  vmstrlower(strcpy(output1DName, mosReducedCategory));
   strcat(output1DName, ".fits");
 
 /* Align WCS to convention used with IFU */
@@ -1755,10 +1763,10 @@ vmmosobsstare(PilSetOfFrames *sof)
     deleteImage(imaSpEx1DCal);
     deleteImage(imaSpEx1D[0]);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1812,10 +1820,10 @@ vmmosobsstare(PilSetOfFrames *sof)
       cpl_msg_error(task, "Failure updating product header");
       deleteImage(imaSpEx1DCal);
       deleteImage(imaSpEx1D[1]);
-      pil_free(imaSpEx1D);
+      cpl_free(imaSpEx1D);
       deleteImage(outSpSkyEx[0]);
       deleteImage(outSpSkyEx[1]);
-      pil_free(outSpSkyEx);
+      cpl_free(outSpSkyEx);
       deleteObjectTable(objectTable);
       deleteWindowTable(windowTable);
       return EXIT_FAILURE;
@@ -1831,7 +1839,7 @@ vmmosobsstare(PilSetOfFrames *sof)
     removeDescriptor(&(imaSpEx1DCal->descs), 
                      pilTrnGetKeyword("TplExposureNumber"));
 
-    strlower(strcpy(output1DName, mosFluxReducedCategory));
+    vmstrlower(strcpy(output1DName, mosFluxReducedCategory));
     strcat(output1DName, ".fits");
 
 /* Align WCS to convention used with IFU */
@@ -1860,10 +1868,10 @@ vmmosobsstare(PilSetOfFrames *sof)
       cpl_msg_error(task, "Cannot create local product file %s!", output1DName);
       deleteImage(imaSpEx1DCal);
       deleteImage(imaSpEx1D[1]);
-      pil_free(imaSpEx1D);
+      cpl_free(imaSpEx1D);
       deleteImage(outSpSkyEx[0]);
       deleteImage(outSpSkyEx[1]);
-      pil_free(outSpSkyEx);
+      cpl_free(outSpSkyEx);
       deleteObjectTable(objectTable);
       deleteWindowTable(windowTable);
       return EXIT_FAILURE;
@@ -1907,10 +1915,10 @@ vmmosobsstare(PilSetOfFrames *sof)
   if (!updateOK) {
     cpl_msg_error(task, "Failure updating product header");
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1926,7 +1934,7 @@ vmmosobsstare(PilSetOfFrames *sof)
   removeDescriptor(&(outSpSkyEx[0]->descs), 
                    pilTrnGetKeyword("TplExposureNumber"));
 
-  strlower(strcpy(output2DName, mosExtractedCategory));
+  vmstrlower(strcpy(output2DName, mosExtractedCategory));
   strcat(output2DName, ".fits");
 
 /* Align WCS to convention used with IFU */
@@ -1954,10 +1962,10 @@ vmmosobsstare(PilSetOfFrames *sof)
   else {
     cpl_msg_error(task, "Cannot create local product file %s!", output2DName);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1999,9 +2007,9 @@ vmmosobsstare(PilSetOfFrames *sof)
   if (!updateOK) {
     cpl_msg_error(task, "Failure updating product header");
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -2016,7 +2024,7 @@ vmmosobsstare(PilSetOfFrames *sof)
   removeDescriptor(&(outSpSkyEx[1]->descs), 
                    pilTrnGetKeyword("TplExposureNumber"));
 
-  strlower(strcpy(output2DSkyName, mosSkyCategory));
+  vmstrlower(strcpy(output2DSkyName, mosSkyCategory));
   strcat(output2DSkyName, ".fits");
 
 /* Align WCS to convention used with IFU */
@@ -2045,9 +2053,9 @@ vmmosobsstare(PilSetOfFrames *sof)
     cpl_msg_error(task, 
                 "Cannot create local product file %s!", output2DSkyName);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -2055,14 +2063,14 @@ vmmosobsstare(PilSetOfFrames *sof)
 
   deleteImage(outSpSkyEx[1]);
 
-  pil_free(outSpSkyEx);
+  cpl_free(outSpSkyEx);
 
   writeStringDescriptor(&(objectTable->descs), pilTrnGetKeyword("DoCategory"),
                         objectTableCategory, "Category of pipeline product");
 
   deleteSetOfDescriptors(&(objectTable->descs), "ESO QC*");
 
-  strlower(strcpy(objectTableName, objectTableCategory));
+  vmstrlower(strcpy(objectTableName, objectTableCategory));
   /* strcat(objectTableName, ".TFITS"); */
   strcat(objectTableName, ".fits");
 
@@ -2096,7 +2104,7 @@ vmmosobsstare(PilSetOfFrames *sof)
 
   if (error) {
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(windowFile);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -2107,7 +2115,7 @@ vmmosobsstare(PilSetOfFrames *sof)
 
   deleteSetOfDescriptors(&(windowTable->descs), "ESO QC*");
 
-  strlower(strcpy(windowTableName, windowTableCategory));
+  vmstrlower(strcpy(windowTableName, windowTableCategory));
   /* strcat(windowTableName, ".TFITS"); */
   strcat(windowTableName, ".fits");
 
@@ -2141,7 +2149,7 @@ vmmosobsstare(PilSetOfFrames *sof)
 
   if (error) {
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     return EXIT_FAILURE;
   }
 
@@ -2177,7 +2185,7 @@ vmmosobsstare(PilSetOfFrames *sof)
   if (!updateOK) {
     cpl_msg_error(task, "Failure updating product header");
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     return EXIT_FAILURE;
   } 
 
@@ -2192,7 +2200,7 @@ vmmosobsstare(PilSetOfFrames *sof)
   removeDescriptor(&(imaSpEx1D[1]->descs),
                    pilTrnGetKeyword("TplExposureNumber"));
 
-  strlower(strcpy(output1DName, mosSkyReducedCategory));
+  vmstrlower(strcpy(output1DName, mosSkyReducedCategory));
   strcat(output1DName, ".fits");
 
 /* Align WCS to convention used with IFU */
@@ -2220,12 +2228,12 @@ vmmosobsstare(PilSetOfFrames *sof)
   else {
     cpl_msg_error(task, "Cannot create local product file %s!", output1DName);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     return EXIT_FAILURE;
   }
 
   deleteImage(imaSpEx1D[1]);
-  pil_free(imaSpEx1D);
+  cpl_free(imaSpEx1D);
 
   return EXIT_SUCCESS;
 
