@@ -68,6 +68,7 @@
 #include "vmmosutils.h"
 #include "vmqcutils.h"
 #include "vmcpl.h"
+#include "vimos_dfs.h"
 
 
 static cxint vmspcaldisp(PilSetOfFrames *);
@@ -910,7 +911,7 @@ vmspcaldisp(PilSetOfFrames *sof)
 
   error = 1;
 
-  if ((lampList = (VimosImage **)pil_calloc(lampCount, sizeof(VimosImage *)))) {
+  if ((lampList = (VimosImage **)cpl_calloc(lampCount, sizeof(VimosImage *)))) {
 
     error = 0;
     arcLampFrame = pilSofLookupNext(sof, arcLampCategory);
@@ -929,7 +930,7 @@ vmspcaldisp(PilSetOfFrames *sof)
         cpl_msg_error(task, "Failure opening arc lamp frame %d", i + 1);
         for (j = 0; j < i; j++)
           deleteImage(lampList[j]);
-        pil_free(lampList);
+        cpl_free(lampList);
         break;
       }
       arcLampFrame = pilSofLookupNext(sof, NULL);
@@ -1004,7 +1005,7 @@ vmspcaldisp(PilSetOfFrames *sof)
       deleteTable(grismTable);
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
+      cpl_free(lampList);
       return EXIT_FAILURE;
     }
 
@@ -1035,7 +1036,7 @@ vmspcaldisp(PilSetOfFrames *sof)
     deleteIfuTable(ifuTable);
     for (i = 0; i < lampCount; i++)
       deleteImage(lampList[i]);
-    pil_free(lampList);
+    cpl_free(lampList);
     return EXIT_FAILURE;
   }
 
@@ -1058,7 +1059,7 @@ vmspcaldisp(PilSetOfFrames *sof)
     deleteImage(biasImage);
     for (i = 0; i < lampCount; i++)
       deleteImage(lampList[i]);
-    pil_free(lampList);
+    cpl_free(lampList);
     return EXIT_FAILURE;
   }
 
@@ -1080,7 +1081,7 @@ vmspcaldisp(PilSetOfFrames *sof)
       deleteImage(biasImage);
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
+      cpl_free(lampList);
       return EXIT_FAILURE;
     }
   }
@@ -1110,7 +1111,7 @@ vmspcaldisp(PilSetOfFrames *sof)
     deleteImage(darkImage);
     for (i = 0; i < lampCount; i++)
       deleteImage(lampList[i]);
-    pil_free(lampList);
+    cpl_free(lampList);
     return EXIT_FAILURE;
   }
 
@@ -1143,7 +1144,7 @@ vmspcaldisp(PilSetOfFrames *sof)
     deleteImage(darkImage);
     for (i = 0; i < lampCount; i++)
       deleteImage(lampList[i]);
-    pil_free(lampList);
+    cpl_free(lampList);
     return EXIT_FAILURE;
   }
 
@@ -1162,7 +1163,7 @@ vmspcaldisp(PilSetOfFrames *sof)
       deleteImage(masterFlatImage);
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
+      cpl_free(lampList);
       return EXIT_FAILURE;
     }
 
@@ -1223,7 +1224,7 @@ vmspcaldisp(PilSetOfFrames *sof)
     deleteImage(combFlatImage);
     for (i = 0; i < lampCount; i++)
       deleteImage(lampList[i]);
-    pil_free(lampList);
+    cpl_free(lampList);
     return EXIT_FAILURE;
   }
 
@@ -1233,7 +1234,7 @@ vmspcaldisp(PilSetOfFrames *sof)
   * before any processing (as bias subtraction, normalization, etc.).
   */
 
-  if ((lampRon = (float *)pil_calloc(lampCount, sizeof(float)))) {
+  if ((lampRon = (float *)cpl_calloc(lampCount, sizeof(float)))) {
     for (i = 0; i < lampCount; i++) {
       lampRon[i] = computeAverageRon(lampList[i]);
     }
@@ -1250,14 +1251,21 @@ vmspcaldisp(PilSetOfFrames *sof)
     deleteImage(combFlatImage);
     for (i = 0; i < lampCount; i++)
       deleteImage(lampList[i]);
-    pil_free(lampList);
+    cpl_free(lampList);
     return EXIT_FAILURE;
   }
 
 
- /*
-  *  Bias removal from arc lamp frames
-  */
+  /*
+   * Now go for the bias subtraction
+   * 
+   * NOTE: This includes the overscan subtraction if biasMethod = BIAS_ZMASTER,
+   * which is the default. Since the overscan region in the master bias has 
+   * been created with growOverscans, there is some extra noise added here,
+   * but this can probably be ignored. A better approach is to use the method
+   * used in the MOS pipeline: subtract overscan for each individual frame,
+   * then subtract bias.
+   */
 
   cpl_msg_info(task, "Bias removal...");
 
@@ -1274,8 +1282,8 @@ vmspcaldisp(PilSetOfFrames *sof)
       deleteImage(combFlatImage);
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
-      pil_free(lampRon);
+      cpl_free(lampList);
+      cpl_free(lampRon);
       return EXIT_FAILURE;
     }
   }
@@ -1303,8 +1311,8 @@ vmspcaldisp(PilSetOfFrames *sof)
         deleteImage(combFlatImage);
         for (i = 0; i < lampCount; i++)
           deleteImage(lampList[i]);
-        pil_free(lampList);
-        pil_free(lampRon);
+        cpl_free(lampList);
+        cpl_free(lampRon);
         return EXIT_FAILURE;
       }
     }
@@ -1325,7 +1333,7 @@ vmspcaldisp(PilSetOfFrames *sof)
     */
 
     error = 1;
-    if ((lampGain = (float *)pil_calloc(lampCount, sizeof(float)))) {
+    if ((lampGain = (float *)cpl_calloc(lampCount, sizeof(float)))) {
       error = 0;
       for (i = 0; i < lampCount; i++) {
         lampGain[i] = getMeanGainFactor(lampList[i]);
@@ -1333,7 +1341,7 @@ vmspcaldisp(PilSetOfFrames *sof)
           error = 1;
           cpl_msg_error(task, 
                       "Wrong or no gain factor for arc lamp frame %d", i + 1);
-          pil_free(lampGain);
+          cpl_free(lampGain);
           break;
         }
       }
@@ -1350,8 +1358,8 @@ vmspcaldisp(PilSetOfFrames *sof)
       deleteImage(combFlatImage);
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
-      pil_free(lampRon);
+      cpl_free(lampList);
+      cpl_free(lampRon);
       return EXIT_FAILURE;
     }
 
@@ -1374,15 +1382,15 @@ vmspcaldisp(PilSetOfFrames *sof)
         deleteImage(combFlatImage);
         for (i = 0; i < lampCount; i++)
           deleteImage(lampList[i]);
-        pil_free(lampList);
-        pil_free(lampGain);
-        pil_free(lampRon);
+        cpl_free(lampList);
+        cpl_free(lampGain);
+        cpl_free(lampRon);
         return EXIT_FAILURE;
       }
       cpl_msg_info(task, "  Arc lamp %d of %zd done", i + 1, lampCount);
     }
 
-    pil_free(lampGain);
+    cpl_free(lampGain);
 
   }
 
@@ -1427,9 +1435,9 @@ vmspcaldisp(PilSetOfFrames *sof)
     deleteImage(combFlatImage);
     for (i = 0; i < lampCount; i++)
       deleteImage(lampList[i]);
-    pil_free(lampList);
-    pil_free(lampGain);
-    pil_free(lampRon);
+    cpl_free(lampList);
+    cpl_free(lampGain);
+    cpl_free(lampRon);
     return EXIT_FAILURE;
   }
 
@@ -1467,8 +1475,8 @@ vmspcaldisp(PilSetOfFrames *sof)
       deleteImage(combFlatImage);
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
-      pil_free(lampRon);
+      cpl_free(lampList);
+      cpl_free(lampRon);
       return EXIT_FAILURE;
     }
 
@@ -1491,8 +1499,8 @@ vmspcaldisp(PilSetOfFrames *sof)
         deleteExtractionTable(extractionTable);
         for (i = 0; i < lampCount; i++)
           deleteImage(lampList[i]);
-        pil_free(lampList);
-        pil_free(lampRon);
+        cpl_free(lampList);
+        cpl_free(lampRon);
         return EXIT_FAILURE;
       }
     }
@@ -1528,8 +1536,8 @@ vmspcaldisp(PilSetOfFrames *sof)
       deleteIfuTable(ifuTable);
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
-      pil_free(lampRon);
+      cpl_free(lampList);
+      cpl_free(lampRon);
       return EXIT_FAILURE;
     }
   }
@@ -1638,14 +1646,14 @@ vmspcaldisp(PilSetOfFrames *sof)
       * Compute lamp level around line position 
       */
 
-      lineShape = (float *)pil_malloc((windowDimen + 1) * sizeof(float));
+      lineShape = (float *)cpl_malloc((windowDimen + 1) * sizeof(float));
 
       for (j = 0; j <= windowDimen; j++) {
         extrLine = extractFloatImage(lampList[i]->data, lampList[i]->xlen,
                                      lampList[i]->ylen, startX, startY + j, 
                                      windowDimen, 1);
         lineShape[j] = medianPixelvalue(extrLine, windowDimen);
-        pil_free(extrLine);
+        cpl_free(extrLine);
       }
 
      /* 
@@ -1682,16 +1690,16 @@ vmspcaldisp(PilSetOfFrames *sof)
         deleteImage(combFlatImage);
         for (i = 0; i < lampCount; i++)
           deleteImage(lampList[i]);
-        pil_free(lampList);
-        pil_free(lampRon);
-        pil_free(lineShape);
+        cpl_free(lampList);
+        cpl_free(lampRon);
+        cpl_free(lineShape);
         return EXIT_FAILURE;
       }
-      pil_free(lineShape);
+      cpl_free(lineShape);
     }
   }                              /* End of validation */
 
-  pil_free(lampRon);
+  cpl_free(lampRon);
 
 
  /*
@@ -1710,13 +1718,13 @@ vmspcaldisp(PilSetOfFrames *sof)
     deleteImage(combFlatImage);
     for (i = 0; i < lampCount; i++)
       deleteImage(lampList[i]);
-    pil_free(lampList);
+    cpl_free(lampList);
     return EXIT_FAILURE;
   }
 
   arcLampImage = stackImages[0];
   deleteImage(stackImages[1]);
-  pil_free(stackImages);
+  cpl_free(stackImages);
 
  /*
   * Bad pixel cleaning
@@ -1738,7 +1746,7 @@ vmspcaldisp(PilSetOfFrames *sof)
       deleteImage(arcLampImage);
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
+      cpl_free(lampList);
       return EXIT_FAILURE;
     }
 
@@ -1763,7 +1771,7 @@ vmspcaldisp(PilSetOfFrames *sof)
       deleteImage(masterFlatImage);
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
+      cpl_free(lampList);
       return EXIT_FAILURE;
     }
   }
@@ -1777,7 +1785,7 @@ vmspcaldisp(PilSetOfFrames *sof)
       deleteImage(arcLampImage); 
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
+      cpl_free(lampList);
       return EXIT_FAILURE;
     }
   }
@@ -1949,7 +1957,7 @@ vmspcaldisp(PilSetOfFrames *sof)
             deleteImage(arcLampImage);
             for (i = 0; i < lampCount; i++)
               deleteImage(lampList[i]);
-            pil_free(lampList);
+            cpl_free(lampList);
             return EXIT_FAILURE;
           }
         }
@@ -1984,7 +1992,7 @@ vmspcaldisp(PilSetOfFrames *sof)
          * Computation of the Spectral Curvature Model
          */
 
-        stackImages = (VimosImage **) pil_calloc(2, sizeof(VimosImage *));
+        stackImages = (VimosImage **) cpl_calloc(2, sizeof(VimosImage *));
         stackImages[0] = combFlatImage;
 
         if (EXIT_SUCCESS == VmSpDerCurves(stackImages, extractionTable, fuzz)) {
@@ -2001,7 +2009,7 @@ vmspcaldisp(PilSetOfFrames *sof)
 
         deleteImage(combFlatImage);
         deleteImage(stackImages[1]);
-        pil_free(stackImages);
+        cpl_free(stackImages);
 
         /*
          * Upgrading the extraction table, according to the new CRV.
@@ -2018,7 +2026,7 @@ vmspcaldisp(PilSetOfFrames *sof)
           deleteImage(arcLampImage);
           for (i = 0; i < lampCount; i++)
             deleteImage(lampList[i]);
-          pil_free(lampList);
+          cpl_free(lampList);
           return EXIT_FAILURE;
         }
       }
@@ -2066,7 +2074,7 @@ vmspcaldisp(PilSetOfFrames *sof)
         deleteImage(arcLampImage); 
         for (i = 0; i < lampCount; i++)
           deleteImage(lampList[i]);
-        pil_free(lampList);
+        cpl_free(lampList);
         return EXIT_FAILURE;
       }
     }
@@ -2081,7 +2089,7 @@ vmspcaldisp(PilSetOfFrames *sof)
         deleteImage(arcLampImage);
         for (i = 0; i < lampCount; i++)
           deleteImage(lampList[i]);
-        pil_free(lampList);
+        cpl_free(lampList);
         return EXIT_FAILURE;
       }
     }
@@ -2104,7 +2112,7 @@ vmspcaldisp(PilSetOfFrames *sof)
       numSlits = 0;
       while(slit) {
         numRows = slit->numRows;
-        buffer = pil_malloc(numRows * sizeof(float));
+        buffer = cpl_malloc(numRows * sizeof(float));
         for (j = 0, k = 0; k < numRows; k++) {
           if (slit->invDisQuality->data[k] != 0) {
             buffer[j] = computeDistModel1D(slit->invDis[k], lambdaCen);
@@ -2124,7 +2132,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
           ++numSlits;
 
         }
-        pil_free(buffer);
+        cpl_free(buffer);
         slit = slit->next;
       }
 
@@ -2164,7 +2172,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
           deleteImage(arcLampImage);
           for (i = 0; i < lampCount; i++)
             deleteImage(lampList[i]);
-          pil_free(lampList);
+          cpl_free(lampList);
           return EXIT_FAILURE;
         }
 
@@ -2182,7 +2190,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
           deleteImage(arcLampImage);
           for (i = 0; i < lampCount; i++)
             deleteImage(lampList[i]);
-          pil_free(lampList);
+          cpl_free(lampList);
           return EXIT_FAILURE;
         }
 
@@ -2213,7 +2221,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
         deleteImage(arcLampImage); 
         for (i = 0; i < lampCount; i++)
           deleteImage(lampList[i]);
-        pil_free(lampList);
+        cpl_free(lampList);
         return EXIT_FAILURE;
       }
 
@@ -2227,7 +2235,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
 
   }
 
-  imabuf = pil_calloc(2, sizeof(VimosImage *));
+  imabuf = cpl_calloc(2, sizeof(VimosImage *));
   imabuf[0] = arcLampImage;
   imabuf[1] = newImageAndAlloc(arcLampImage->xlen, arcLampImage->ylen);
 
@@ -2254,7 +2262,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
       deleteExtractionTable(extractionTable);
       for (i = 0; i < lampCount; i++)
         deleteImage(lampList[i]);
-      pil_free(lampList);
+      cpl_free(lampList);
       return EXIT_FAILURE;
     }
 
@@ -2267,10 +2275,10 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
   extracted2D = extr2D[0];
 
   deleteImage(extr2D[1]); 
-  pil_free(extr2D);
+  cpl_free(extr2D);
 
   deleteImage(imabuf[1]);
-  pil_free(imabuf);
+  cpl_free(imabuf);
 
 /* * 
   createFitsImage("extr2D.fits", extracted2D, "cat");
@@ -2440,7 +2448,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
       
       numRows = slit->numRows;
 
-      buffer = (float *)pil_malloc(numRows * sizeof(float));
+      buffer = (float *)cpl_malloc(numRows * sizeof(float));
 
       for (i = 0; i <= (unsigned int)idsOrd; i++) {
         npix = 0;
@@ -2479,7 +2487,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
 
       }
 
-      pil_free(buffer);
+      cpl_free(buffer);
 
 
       /*
@@ -2494,7 +2502,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
         slit = slit->next;
       }
 
-      buffer = (float *)pil_malloc(numRows * sizeof(float));
+      buffer = (float *)cpl_malloc(numRows * sizeof(float));
 
       slit = extractionTable->slits;
 
@@ -2527,7 +2535,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
                          "QC.MOS.REFWAVE.RMS", "pixel",
                          "RMS of CCD positions of reference wavelength");
 
-      pil_free(buffer);
+      cpl_free(buffer);
 
 
       /*
@@ -2730,7 +2738,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
 
   for (i = 0; i < lampCount; i++)
     deleteImage(lampList[i]);
-  pil_free(lampList);
+  cpl_free(lampList);
 
   deleteImage(arcLampImage);
 
@@ -2792,7 +2800,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
   * Output the primary product: the Extraction Table
   */
 
-  strlower(strcpy(outputExtrName, extrTableCategory));
+  vmstrlower(strcpy(outputExtrName, extrTableCategory));
   /* strcat(outputExtrName, ".TFITS"); */
   strcat(outputExtrName, ".fits");
 
@@ -2864,7 +2872,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
     pilFrmSetProductType(outputFrame, PIL_PRODUCT_TYPE_REDUCED);
 
     pilSofInsert(sof, outputFrame);
-    pil_free(pafFileName);
+    cpl_free(pafFileName);
   }
   else {
     deleteExtractionTable(extractionTable);
@@ -2875,7 +2883,7 @@ printf("x = %.2f  y = %.2f  i = %.2f + %.2f\n", coefArrayY[numSlits].x, coefArra
 
   deleteExtractionTable(extractionTable);
 
-  strlower(strcpy(extrArcName, arc2DCatg));
+  vmstrlower(strcpy(extrArcName, arc2DCatg));
   strcat(extrArcName, ".fits");
 
 
