@@ -36,7 +36,6 @@
 #include <cpl.h>
 #include <moses.h>
 #include <vimos_dfs.h>
-#include <fors_qc.h>
 #include <vimos_calib_impl.h>
 
 #include "vimos_grism.h"
@@ -1045,7 +1044,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     else if(slit_ident && treat_as_lss)
     {
         /* In this case we perform a slit identification based purely on 
-         * the slits X positions rahter than pattern matching.
+         * the slits X positions rather than pattern matching.
          */
         cpl_msg_info(cpl_func, "Performing LSS slit identification");
         
@@ -1321,124 +1320,11 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
                    cpl_table_get_column_mean(restab, "fwhm") / dispersion,
                    cpl_table_get_column_mean(restab, "fwhm_rms") / dispersion);
 
-        if (0) {
 
-            header = dfs_load_header(frameset, arc_tag, 0);
-
-            if (header == NULL)
-                vimos_calib_exit("Cannot reload arc lamp header");
-
-            qclist = cpl_propertylist_new();
-
-            fors_qc_start_group(qclist, "1.1", instrume);
-
-
-            /*
-             * QC1 group header
-             */
-
-            if (fors_qc_write_string("PRO.CATG", spectral_resolution_tag,
-                                    "Product category", instrume))
-                vimos_calib_exit("Cannot write product category to "
-                                "QC log file");
-
-            if (fors_qc_keyword_to_paf(header, "ESO DPR TYPE", NULL,
-                                      "DPR type", instrume))
-                vimos_calib_exit("Missing keyword DPR TYPE in arc "
-                                "lamp header");
-
-            if (fors_qc_keyword_to_paf(header, "ESO TPL ID", NULL,
-                                      "Template", instrume))
-                vimos_calib_exit("Missing keyword TPL ID in arc "
-                                "lamp header");
-
-            if (fors_qc_keyword_to_paf(header, key_gris_name, NULL,
-                                      "Grism name", instrume)) {
-                cpl_msg_error(recipe, "Missing keyword %s in arc "
-                                "lamp header", key_gris_name);
-                vimos_calib_exit(NULL);
-            }
-
-            if (fors_qc_keyword_to_paf(header, key_gris_id, NULL,
-                                      "Grism identifier", instrume)) {
-                cpl_msg_error(recipe, "Missing keyword %s in arc "
-                                "lamp header", key_gris_id);
-                vimos_calib_exit(NULL);
-            }
-
-            if (cpl_propertylist_has(header, key_filt_name))
-                fors_qc_keyword_to_paf(header, key_filt_name, NULL,
-                                      "Filter name", instrume);
-
-            if (fors_qc_keyword_to_paf(header, "ESO DET CHIP1 ID", NULL,
-                                      "Chip identifier", instrume))
-                vimos_calib_exit("Missing keyword DET CHIP1 ID in arc "
-                                "lamp header");
-
-            if (fors_qc_keyword_to_paf(header, "ARCFILE", NULL,
-                                      "Archive name of input data", 
-                                      instrume))
-                vimos_calib_exit("Missing keyword ARCFILE in arc "
-                                "lamp header");
-
-            cpl_propertylist_delete(header); header = NULL;
-
-
-            /*
-             * QC1 parameters
-             */
-
-            keyname = "QC.MOS.RESOLUTION";
-
-            if (fors_qc_write_qc_double(qclist, 
-                                       cpl_table_get_column_mean(restab,
-                                                                 "resolution"),
-                                       keyname,
-                                       "Angstrom",
-                                       "Mean spectral resolution",
-                                       instrume)) {
-                vimos_calib_exit("Cannot write mean spectral resolution to QC "
-                                "log file");
-            }
-
-            keyname = "QC.MOS.RESOLUTION.RMS";
-
-            if (fors_qc_write_qc_double(qclist, 
-                                       cpl_table_get_column_stdev(restab, 
-                                                                  "resolution"),
-                                       "QC.MOS.RESOLUTION.RMS",
-                                       "Angstrom", 
-                                       "Scatter of spectral resolution",
-                                       instrume)) {
-                vimos_calib_exit("Cannot write spectral resolution scatter "
-                                "to QC log file");
-            }
-
-            keyname = "QC.MOS.RESOLUTION.NLINES";
-
-            if (fors_qc_write_qc_int(qclist, cpl_table_get_nrow(restab) -
-                                    cpl_table_count_invalid(restab, 
-                                                            "resolution"),
-                                    "QC.MOS.RESOLUTION.NLINES",
-                                    NULL,
-                                    "Number of lines for spectral resolution "
-                                    "computation",
-                                    instrume)) {
-                vimos_calib_exit("Cannot write number of lines used in "
-                                "spectral resolution computation "
-                                "to QC log file");
-            }
-
-            fors_qc_end_group();
-
-        }
-
-        if (dfs_save_table(frameset, restab, spectral_resolution_tag, qclist,
+        if (dfs_save_table(frameset, restab, spectral_resolution_tag, NULL,
                            parlist, recipe, version))
             vimos_calib_exit(NULL);
 
-        cpl_propertylist_delete(qclist); qclist = NULL;
-
     }
     else
         vimos_calib_exit("Cannot compute the spectral resolution table");
@@ -1961,8 +1847,8 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
 
     /* Compute master flat.
      * TODO: master flat has already been computed above using the old method
-     * Here we use the new method and is the one saved. The other is not yet
-     * deleted in case it is used for something else.
+     * Here we use the new method and is the one saved as a product. The other 
+     * is not yet deleted in case it is used for something else.
      */
     cpl_msg_indent_less();
     cpl_msg_info(recipe, "Perform flat field combination...");
@@ -1990,7 +1876,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
 
     vimos::flat_normaliser normaliser;
     normaliser.mos_normalise(*norm_flat, wave_cal,
-                             coordinate, slits, polytraces,
+                             coordinate, calib_slits, slits, polytraces,
                              startwavelength, endwavelength,
                              dispersion, sradius, dradius,
                              spa_polyorder, disp_nknots, fit_threshold);
