@@ -854,13 +854,8 @@ int dfs_save_image(cpl_frameset *frameset, const cpl_image *image,
     else
         plist = cpl_propertylist_duplicate(header);
 
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(4, 8, 0)
     if (cpl_dfs_setup_product_header(plist, frame, frameset, parlist,
                                      recipename, version, "PRO-1.15", NULL)) {
-#else 
-    if (cpl_dfs_setup_product_header(plist, frame, frameset, parlist,
-                                     recipename, version, "PRO-1.15")) {
-#endif
         cpl_msg_error(cpl_error_get_where(), "%s", cpl_error_get_message());
         cpl_msg_error(func, "Problem with product %s FITS header definition",
                       category);
@@ -995,13 +990,8 @@ int dfs_save_table(cpl_frameset *frameset, const cpl_table *table,
     else
         plist = header;
 
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(4, 8, 0)
     if (cpl_dfs_setup_product_header(plist, frame, frameset, parlist,
                                      recipename, version, "PRO-1.15", NULL)) {
-#else 
-    if (cpl_dfs_setup_product_header(plist, frame, frameset, parlist,
-                                     recipename, version, "PRO-1.15")) {
-#endif
         cpl_msg_error(cpl_error_get_where(), "%s", cpl_error_get_message());
         cpl_msg_error(func, "Problem with product %s FITS header definition",
                       category);
@@ -1295,15 +1285,9 @@ cpl_error_code dfs_save_image_null(cpl_frameset * frameset,
     vmstrlower(strcpy(filename, tag));
     strcat(filename, ".fits");
 
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(4, 8, 0)
     error = cpl_dfs_save_image(frameset, NULL, parlist, frameset, NULL, NULL,
 			       CPL_BPP_IEEE_FLOAT, recipename, pro,
 			       regexp, version, filename);
-#else
-    error = cpl_dfs_save_image(frameset, parlist, frameset, NULL,
-			       CPL_BPP_IEEE_FLOAT, recipename, tag,
-			       NULL, regexp, version, filename);
-#endif
     
     cpl_free(filename);
     cpl_propertylist_delete(pro);
