@@ -31,12 +31,12 @@
 
 #include <cmath>
 #include <functional>
-#include <vimos_flat_normalise.h>
-#include <moses.h>
-#include <image_smooth.h>
-#include <vector_utils.h>
-#include <image_spline_fit.h>
-#include <image_normalisation.h>
+#include "vimos_flat_normalise.h"
+#include "moses.h"
+#include "image_smooth.h"
+#include "vector_utils.h"
+#include "image_spline_fit.h"
+#include "image_normalisation.h"
 
 #define STRETCH_FACTOR   (1.20)
 
@@ -54,18 +54,22 @@ vimos::flat_normaliser::~flat_normaliser()
  *   Normalise a flat field exposure
  *  
  * @param flat        Image containing the original flat field spectra
+ * @param wave_cal    The wavelength calibration
  * @param spatial     Spatial calibration image
  * @param slits       Table with slits positions
  * @param polytraces  Coefficients of spectral curvature polynomials
- * @param reference   Reference wavelength
  * @param blue        Start lambda to process
  * @param red         End lambda to process
  * @param dispersion  Mean spectral dispersion
- * @param sradius     Radius of smoothing box along the dispersion direction
- * @param polyorder   Order of fitting polynomial along the dispersion
+ * @param spa_smooth_radius   Number of pixels for smoothing kernel in spatial axis
+ * @param disp_smooth_radius  Number of pixels for smoothing kernel in dispersion axis
+ * @param spa_fit_polyorder   Order for polynomial fit along spatial axis
+ * @param disp_fit_knots      Number of knots in the spline fitting along dispersion axis
+ * @param fit_threshold       values below this will be igonred in the fits 
  *  
  * @return The smoothed flat field exposure used for normalisation
  *
+ * TODO: rewrite
  * The input @em flat frame should be already bias subtracted, and should
  * be oriented so that the dispersion direction is horizontal with @em blue
  * on the left and @em red on the right. The flat field spectra are spatially 
@@ -83,7 +87,9 @@ vimos::flat_normaliser::~flat_normaliser()
  */ 
 int vimos::flat_normaliser::mos_normalise
 (mosca::image& flat, const mosca::wavelength_calibration& wave_cal,
- cpl_image *spatial, cpl_table *slits, cpl_table *polytraces, 
+ cpl_image *spatial, 
+ const std::vector<mosca::calibrated_slit>& calib_slits,
+ cpl_table *slits, cpl_table *polytraces, 
  double blue, double red, 
  double dispersion,
  int spa_smooth_radius, int disp_smooth_radius, 
@@ -111,7 +117,6 @@ int vimos::flat_normaliser::mos_normalise
     double          ypos;
     double          fvalue;
     int             ivalue;
-    int             yint, yprev = 0;
     int             npseudo;
 
     int             pixel_above, pixel_below, refpixel, start_pixel, end_pixel;
@@ -146,7 +151,6 @@ int vimos::flat_normaliser::mos_normalise
     
     cpl_image * flat_im = flat.get_cpl_image();
     cpl_image * flat_err = flat.get_cpl_image_err();
-
     
     double reference = wave_cal.get_refwave();
     rectified = mos_spatial_calibration(flat_im, slits, polytraces, reference,
@@ -203,7 +207,35 @@ int vimos::flat_normaliser::mos_normalise
         cpl_image * exslit_orig =
                 cpl_image_extract(rectified, xlow, ylow, xhig, yhig);
         mosca::image im_exslit_orig(exslit_orig, true);
-        
+
+        //Get a mask of valid pixels of the slit in the rectified space
+        std::vector<mosca::calibrated_slit>::const_iterator slit_it; 
+        for(std::vector<mosca::calibrated_slit>::const_iterator it = calib_slits.begin();
+            it != calib_slits.end(); ++it) //Life would be easier with a lambda...
+        {
+            if(it->slit_id() == slit_id[i])
+            {
+                slit_it = it; 
+                break;
+            }
+        }
+        cpl_mask * slit_mask_whole =
+                slit_it->get_mask_valid(flat.dispersion_axis());
+        cpl_image * slit_mask_im = cpl_image_new_from_mask(slit_mask_whole);
+        cpl_image * slit_mask_im_d =  cpl_image_cast(slit_mask_im, CPL_TYPE_FLOAT);
+        cpl_image * slit_mask_rectified = 
+                mos_spatial_calibration(slit_mask_im_d, slits, polytraces, 
+                                        reference, blue, red, dispersion, 
+                                        0, NULL);
+        //We don't consider fractional pixels yet
+        cpl_image_threshold(slit_mask_rectified, 0.75, 1.25, 0., 1.);
+        cpl_image * exslit_mask_rectified =
+                cpl_image_extract(slit_mask_rectified, xlow, ylow, xhig, yhig);
+        mosca::image slit_mask_im_mos(exslit_mask_rectified, true);
+        cpl_image_delete(slit_mask_rectified);
+        cpl_image_delete(slit_mask_im);
+        cpl_image_delete(slit_mask_im_d);
+
         int  final_spa_smooth_radius = spa_smooth_radius;
         if (im_exslit_orig.size_spatial() / 2 < spa_smooth_radius)
         {
@@ -216,7 +248,8 @@ int vimos::flat_normaliser::mos_normalise
         
         std::vector<float> slit_spa_norm_profile;
         std::vector<float> slit_disp_norm_profile;
-        mosca::image normslit = mosca::image_normalise<float>(im_exslit_orig, 
+        mosca::image normslit = mosca::image_normalise(im_exslit_orig,
+                                      slit_mask_im_mos,
                                       final_spa_smooth_radius, disp_smooth_radius,
                                       spa_fit_polyorder, disp_fit_nknots, 
                                       fit_threshold, slit_spa_norm_profile,
@@ -332,19 +365,21 @@ int vimos::flat_normaliser::mos_normalise
         ny = cpl_image_get_size_y(flat_im);
 
         sdata = cpl_image_get_data_float(spatial);
+        cpl_binary * slit_mask_data = cpl_mask_get_data(slit_mask_whole);
         xdata = cpl_image_get_data_float(exslit);
         npseudo = cpl_image_get_size_y(exslit) - 1;
 
         /*
          * Write interpolated smoothed values to CCD image
          */
-
-        for (j = start_pixel; j < end_pixel; j++) {
-            top = cpl_polynomial_eval_1d(polytop, j, NULL);
-            bot = cpl_polynomial_eval_1d(polybot, j, NULL);
-            for (k = 0; k <= npseudo; k++) {
-                ypos = top - k*(top-bot)/npseudo;
-                yint = (int)(ypos);
+        int disp_bottom, spa_bottom, disp_top, spa_top;
+        slit_it->get_extent_pix(disp_bottom, spa_bottom, disp_top, spa_top);
+        for (j = start_pixel; j < end_pixel; j++) 
+        {
+            for (int yint = spa_bottom; yint <= spa_top; yint++) 
+            {
+                if (slit_mask_data[j + nx*yint] == CPL_BINARY_0)
+                    continue;
 
                 /*
                  * The line:
@@ -353,45 +388,23 @@ int vimos::flat_normaliser::mos_normalise
                  *     value = npseudo*(top-yint)/(top-bot);
                  */
 
-                if (yint < 0 || yint >= ny-1) {
-                    yprev = yint;
-                    continue;
-                }
 
-                value = sdata[j + nx*yint];   /* Spatial coordinate on CCD */
-                ivalue = (int)(value);        /* Nearest spatial pixels:   */
+                value = sdata[j + nx*yint];   /* Spatial coordinate on rectified space */
+                ivalue = std::floor(value);        /* Nearest spatial pixels:   */
                 fvalue = value - ivalue;      /* ivalue and ivalue+1       */
                 if (ivalue < npseudo && ivalue >= 0) {
                     vtop = xdata[j + nx*(npseudo-ivalue)];
                     vbot = xdata[j + nx*(npseudo-ivalue-1)];
                     wdata[j + nx*yint] = vtop*(1-fvalue) + vbot*fvalue;
-
-                    if (k) {
-
-                        /*
-                         * This is added to recover lost pixels on
-                         * the CCD image (pixels are lost because
-                         * the CCD pixels are less than npseudo+1).
-                         */
-
-                        if (yprev - yint > 1) {
-                            value = sdata[j + nx*(yint+1)];
-                            ivalue = (int)(value);
-                            fvalue = value - ivalue;
-                            if (ivalue < npseudo && ivalue >= 0) {
-                                vtop = xdata[j + nx*(npseudo-ivalue)];
-                                vbot = xdata[j + nx*(npseudo-ivalue-1)];
-                                wdata[j + nx*(yint+1)] = vtop*(1-fvalue) 
-                                                       + vbot*fvalue;
-                            }
-                        }
-                    }
                 }
-                yprev = yint;
+                else if (ivalue == npseudo)
+                    wdata[j + nx*yint] = xdata[j]; //j+nx*(npseudo-npseudo)
+                
             }
         }
         cpl_polynomial_delete(polytop);
         cpl_polynomial_delete(polybot);
+        cpl_mask_delete(slit_mask_whole);
     }
     
     //TODO: What happens with inter-slit flux conservation. In principle the overall level
