@@ -40,7 +40,6 @@
 #include <moses.h>
 #include <fors_tools.h>
 #include <vimos_dfs.h>
-#include <fors_qc.h>
 
 #include "vimos_overscan.h"
 #include "vimos_detmodel.h"
@@ -352,9 +351,6 @@ int vimos_science_impl(cpl_frameset *frameset, cpl_parameterlist *parlist,
     if (resp_fit_degree > 0 && resp_fit_nknots > 0 )
         vimos_science_exit("Only spline or polynomial fitting of response allowed, but not both");
 
-    if (resp_fit_degree < 0 && resp_fit_nknots < 0 )
-        vimos_science_exit("Either spline or polynomial fitting of response has to be specified");
-
     resp_ignore_mode = dfs_get_parameter_string(parlist, 
                     "vimos.vmmosscience.resp_ignore_mode", NULL);
 
@@ -617,11 +613,11 @@ int vimos_science_impl(cpl_frameset *frameset, cpl_parameterlist *parlist,
             CPL_TYPE_FLOAT, 0, 1);
     master_bias_err = dfs_load_image(frameset, "MASTER_BIAS", 
             CPL_TYPE_FLOAT, 1, 1);
-    cpl_image * master_bias_var = cpl_image_power_create(master_bias_err, 2);
     cpl_propertylist * master_bias_header = 
             dfs_load_header(frameset, "MASTER_BIAS", 0);
     if (master_bias == NULL || master_bias_err == NULL || master_bias_header == NULL)
         vimos_science_exit("Cannot load master bias. Maybe error extension is missing");
+    cpl_image * master_bias_var = cpl_image_power_create(master_bias_err, 2);
     cpl_image_delete(master_bias_err); master_bias_err = NULL;
 
     /*
@@ -630,6 +626,16 @@ int vimos_science_impl(cpl_frameset *frameset, cpl_parameterlist *parlist,
 
     exptime = (double *)cpl_calloc(nscience, sizeof(double));
 
+    //TODO: it looks like the code after the if is never executed, since the 
+    //sof always comes with one single science. The case of more science is 
+    //treated specially by the vimos_science_mult() function in vimos_science.cc
+    //which in turn calls this function but then only for each individual frame.
+    //The problem is that there is then a lot of code duplication.
+    //Note that the average in vimos_science.cc takes into account the
+    //shifts, whereas the code below simply performs a median.
+    //Also, the average here is of the raw frames, whereas in vimos_science.cc
+    //it makes an average of the unmmaped frames, which are already
+    //half-processed.
     if (nscience > 1) {
 
         cpl_msg_info(recipe, "Load %d scientific frames and median them...",
@@ -1604,6 +1610,10 @@ int vimos_science_impl(cpl_frameset *frameset, cpl_parameterlist *parlist,
 
         if (images) {
             if (standard) {
+              if (resp_fit_degree < 0 && resp_fit_nknots < 0 )
+                  vimos_science_exit("Either spline or polynomial fitting "
+                                     "of response has to be specified");
+
                 cpl_table *ext_table  = NULL;
                 cpl_table *flux_table = NULL;
                 cpl_table *telluric_table = NULL;
