@@ -2765,14 +2765,14 @@ VimosImage *openOldFitsFile(const char *fileName, int imaFlag, int readFlag)
   status = 0;
 
   if (readFlag == 0) {
-    if (fits_open_file( &fptr, fileName, READONLY, &status)) {
-         cpl_msg_error(modName, "fits_open_file returned error %d)", status);
+    if (ffopen( &fptr, fileName, READONLY, &status)) {
+         cpl_msg_error(modName, "ffopen returned error %d)", status);
 	 return(NULL);
     }
   }
   if (readFlag == 1) {
-    if (fits_open_file( &fptr, fileName, READWRITE, &status)) {
-         cpl_msg_error(modName, "fits_open_file returned error %d", status);
+    if (ffopen( &fptr, fileName, READWRITE, &status)) {
+         cpl_msg_error(modName, "ffopen returned error %d", status);
 	 return(NULL);
     }
   }
