@@ -1005,8 +1005,7 @@ int calcres(VimosTable *o_star, VimosTable *a_star, int imatch[], int nmatch,
   *(rms+1) = dysum / dmatch;
   *(rms+2) = dxwldsum / dmatch;
   *(rms+3) = dywldsum / dmatch;
-  *(rms+4) = 0.;
       
-    return VM_TRUE;
+  return VM_TRUE;
 }
 /**@}*/
