@@ -46,6 +46,7 @@
 #include "vmmosutils.h"
 #include "vmifuutils.h"
 #include "vmmosmodels.h"
+#include "cpl.h"
 
 
 /**
@@ -279,7 +280,7 @@ VmSpDerCurves(VimosImage **imageData, VimosExtractionTable *extractionTable,
 
 	/* delete array with coefficients, if it exists */
 	if (curve!= NULL) {
-	  pil_free(curve);
+	  cpl_free(curve);
 	  curve = NULL;
 	}
 	/* delete the existing curvature polynomials in slit, in case the order
@@ -317,7 +318,7 @@ VmSpDerCurves(VimosImage **imageData, VimosExtractionTable *extractionTable,
 	  slit->ccdX->data[i] += (int) xOffset;
     
 	/* free buffer */
-	pil_free(curve);
+	cpl_free(curve);
 	curve = NULL;
     
 	/* same story for upper edge of slit */
@@ -422,7 +423,7 @@ VmSpDerCurves(VimosImage **imageData, VimosExtractionTable *extractionTable,
   
   /* clean up... */
   if (curve != NULL) {
-    pil_free(curve);
+    cpl_free(curve);
   }
   deleteDpoint(upper);
   deleteDpoint(lower);
