@@ -987,7 +987,7 @@ static PilFrame *get_raw_frame_time_sequence(PilSetOfFrames *framelist, int seq)
     while (frame != NULL) {
         if (pilFrmGetType(frame) == PIL_FRAME_TYPE_RAW
             || pilFrmGetType(frame) == PIL_FRAME_TYPE_UNDEF) {
-            if (fits_open_file(&fptr, pilFrmGetName(frame), READONLY, &status))
+            if (ffopen(&fptr, pilFrmGetName(frame), READONLY, &status))
             {
                 fits_get_errstatus(status, errText);
                 cpl_msg_error(fid, "Opening file %s: %s",
@@ -1022,7 +1022,7 @@ static PilFrame *get_raw_frame_time_sequence(PilSetOfFrames *framelist, int seq)
     while (frame != NULL) {
         if (pilFrmGetType(frame) == PIL_FRAME_TYPE_RAW
             || pilFrmGetType(frame) == PIL_FRAME_TYPE_UNDEF) {
-            if (fits_open_file(&fptr, pilFrmGetName(frame), READONLY, &status))
+            if (ffopen(&fptr, pilFrmGetName(frame), READONLY, &status))
             {
                 fits_get_errstatus(status, errText);
                 cpl_msg_error(fid, "Opening file %s: %s",
@@ -1068,8 +1068,9 @@ static PilFrame *get_raw_frame_time_sequence(PilSetOfFrames *framelist, int seq)
         }
     }
 
+    free(times);
+    free(sort_frames);
     return NULL;
-
 }
 
 
@@ -1167,7 +1168,7 @@ int vm_dfs_setup_product_header(PilFrame *proFrame, const char *recipename,
     while (frame != NULL) {
         if (pilFrmGetType(frame) == PIL_FRAME_TYPE_RAW 
             || pilFrmGetType(frame) == PIL_FRAME_TYPE_UNDEF) {
-            if (fits_open_file(&fptr, pilFrmGetName(frame), READONLY, &status))
+            if (ffopen(&fptr, pilFrmGetName(frame), READONLY, &status))
             {
                 fits_get_errstatus(status, errText);
                 cpl_msg_error(fid, "Opening file %s: %s",
@@ -1218,14 +1219,14 @@ int vm_dfs_setup_product_header(PilFrame *proFrame, const char *recipename,
      * product header.
      */
 
-    if (fits_open_file(&ifptr, pilFrmGetName(first_frame), READONLY, &status)) {
+    if (ffopen(&ifptr, pilFrmGetName(first_frame), READONLY, &status)) {
         fits_get_errstatus(status, errText);
         cpl_msg_error(fid, "Opening file %s: %s", 
                       pilFrmGetName(first_frame), errText);
         return EXIT_FAILURE;
     }
 
-    if (fits_open_file(&ofptr, productName, READWRITE, &status)) {
+    if (ffopen(&ofptr, productName, READWRITE, &status)) {
         fits_get_errstatus(status, errText);
         cpl_msg_error(fid, "Opening file %s: %s", productName, errText);
         status = 0;
@@ -1776,7 +1777,7 @@ int vm_dfs_setup_product_header(PilFrame *proFrame, const char *recipename,
 
             snprintf(cval, FLEN_CARD, PRO_REC_CALi_DATAMD5, ncal);
 
-            if (fits_open_file(&fptr, pilFrmGetName(frame), READONLY, &status))
+            if (ffopen(&fptr, pilFrmGetName(frame), READONLY, &status))
             {
                 fits_get_errstatus(status, errText);
                 cpl_msg_error(fid, "Opening file %s: %s",
