@@ -41,6 +41,7 @@
 
 #include "vmtable.h"
 #include "vmwindowtable.h"
+#include "cpl.h"
 
 /*
  * Returns a pointer to a new Window Object
@@ -51,7 +52,7 @@ VimosWindowObject *newWindowObject(void)
   VimosWindowObject *newObject;
   
   /* allocate memory for Window Object */
-  newObject = (VimosWindowObject *) pil_malloc(sizeof(VimosWindowObject));
+  newObject = (VimosWindowObject *) cpl_malloc(sizeof(VimosWindowObject));
   
   /* check if space was allocated */
   if (newObject == NULL) {
@@ -98,7 +99,7 @@ void deleteWindowObject(VimosWindowObject *obj)
     /* get address of next object */
     nextObj = tmpObj->next;
     /* free current object */
-    pil_free(tmpObj);
+    cpl_free(tmpObj);
     /* next one to process */
     tmpObj = nextObj;
   }
@@ -114,7 +115,7 @@ VimosWindowSlit *newWindowSlit()
   VimosWindowSlit *newSlit;
   
   /* allocate memory for WindowSlit */
-  newSlit = (VimosWindowSlit *) pil_malloc(sizeof(VimosWindowSlit));
+  newSlit = (VimosWindowSlit *) cpl_malloc(sizeof(VimosWindowSlit));
   
   /* check if space was allocated */
   if (newSlit == NULL) {
@@ -157,7 +158,7 @@ void deleteWindowSlit(VimosWindowSlit *wSlit)
     /* get address of next slit */
     nextSlit = tmpSlit->next;
     /* free currebt slit */
-    pil_free(tmpSlit);
+    cpl_free(tmpSlit);
     /* next one to process */
     tmpSlit = nextSlit;
   }
@@ -173,7 +174,7 @@ VimosWindowTable *newWindowTable()
   VimosWindowTable *newTab;
   
   /* allocate new VimosTable */
-  newTab = (VimosWindowTable *) pil_malloc(sizeof(VimosWindowTable));
+  newTab = (VimosWindowTable *) cpl_malloc(sizeof(VimosWindowTable));
 
   /* check if space was allocated */
   if (newTab == NULL) {
@@ -186,7 +187,7 @@ VimosWindowTable *newWindowTable()
   newTab->descs = newStringDescriptor("ESO PRO TABLE", VM_WIN, "");
   if (newTab->descs == NULL) {
     /* cleanup */
-    pil_free(newTab);
+    cpl_free(newTab);
     cpl_msg_error("newWindowTable","The function newStringDescriptor has returned NULL");
     return(NULL);
   }
@@ -580,9 +581,9 @@ VimosBool readFitsWindowTable(VimosWindowTable *winTable, fitsfile *fptr)
   }
 
   /* allocate space for the column labels */
-  ttype = (char **) pil_malloc(nCols*sizeof(char *));
+  ttype = (char **) cpl_malloc(nCols*sizeof(char *));
   for (i=0; i < nCols; i++) {
-    ttype[i] = (char *) pil_malloc(FLEN_VALUE*sizeof(char));
+    ttype[i] = (char *) cpl_malloc(FLEN_VALUE*sizeof(char));
     /* check if space was allocated */
     if (ttype[i] == NULL) {
       cpl_msg_error("readFitsWindowTable","Allocation Error");
@@ -855,7 +856,7 @@ VimosBool readFitsWindowTable(VimosWindowTable *winTable, fitsfile *fptr)
   }
 
   for (ii = 0; ii < 3; ii++){     /* free the memory for the column labels */
-    pil_free( ttype[ii] );
+    cpl_free( ttype[ii] );
   }
 
   return (VM_TRUE);
@@ -913,13 +914,13 @@ VimosBool writeFitsWindowTable(VimosWindowTable *winTable, fitsfile *fptr)
   /* ALEX: added IFUfibTrans => i<=15 instead of 14 */
   
   for (i = 0; i <= 15; i++){      /* allocate space for the column labels */
-    ttype[i] = (char *) pil_malloc(FLEN_VALUE);  /* max label length = 69 */
+    ttype[i] = (char *) cpl_malloc(FLEN_VALUE);  /* max label length = 69 */
     /* check if space was allocated */
     if (ttype[i] == NULL) {
       cpl_msg_error("writeFitsWindowTable","Allocation Error");
       return (VM_FALSE);
     }
-    tform[i] = (char *) pil_malloc(FLEN_VALUE);
+    tform[i] = (char *) cpl_malloc(FLEN_VALUE);
     /* check if space was allocated */
     if (tform[i] == NULL) {
       cpl_msg_error("writeFitsWindowTable","Allocation Error");
